#!/bin/sh
export PYTHONPATH=${BUILDER_TOP_DIR}/Source
export LD_LIBRARY_PATH=${SVNCPP_LIB}
export DYLD_LIBRARY_PATH=${SVNCPP_LIB}
${PYTHON} $*
